@@ -192,7 +192,9 @@ class PrimeHub(object):
     def __init__(self, config: PrimeHubConfig):
         self.primehub_config = config
         self.json_output = True
+        self.usage_role = 'user'
         self.commands: Dict[str, Module] = dict()
+        self.admin_commands: Dict[str, Module] = dict()
         self._stderr = sys.stderr
         self._stdout = sys.stdout
 
@@ -209,6 +211,15 @@ class PrimeHub(object):
         self.register_command('files', 'Files')
         self.register_command('me', 'Me')
         self.register_command('version', 'Version')
+        self.register_command('apptemplates', 'AppTemplate')
+        self.register_command('apps', 'Apps')
+        self.register_command('models', 'Models')
+        self.register_dummy_command('admin', 'Commands for system administrator')
+
+        # register admin commands
+        self.register_admin_command('admin_datasets', 'AdminDatasets', 'datasets')
+        self.register_admin_command('admin_instancetypes', 'AdminInstanceTypes', 'instancetypes')
+        self.register_admin_command('admin_users', 'AdminUsers', 'users')
 
         # initial
         self._ensure_config_details(config)
@@ -234,19 +245,47 @@ class PrimeHub(object):
     def request_file(self, endpint: str, dest: str):
         return Client(self.primehub_config).request_file(endpint, dest)
 
-    def register_command(self, module_name: str, command_class: Union[str, Callable], command_name=None):
-        if not command_name:
-            command_name = module_name
-
+    def _find_command_class(self, command_class, module_name):
         # create command instance
         if isinstance(command_class, str):
             clazz = importlib.import_module('primehub.' + module_name).__getattribute__(command_class)
         else:
             clazz = command_class
+        return clazz
+
+    def register_command(self, module_name: str, command_class: Union[str, Callable], command_name=None):
+        if not command_name:
+            command_name = module_name
+
+        clazz = self._find_command_class(command_class, module_name)
 
         # register to the commands table
         self.commands[command_name] = clazz(self)
 
+    def register_dummy_command(self, command_name, command_help):
+
+        # register to the commands table
+        self.commands[command_name] = Dummy(self, command_help)
+
+    def register_admin_command(self, module_name: str, command_class: Union[str, Callable], command_name=None):
+        if not command_name:
+            command_name = module_name
+
+        clazz = self._find_command_class(command_class, module_name)
+
+        # register to the commands table
+        self.admin_commands[command_name] = clazz(self)
+
+    def switch_admin_role(self):
+        self.usage_role = 'admin'
+        self.commands = self.admin_commands
+
+    @property
+    def admin(self):
+        admin_primehub = PrimeHub(self.primehub_config)
+        admin_primehub.commands = self.admin_commands
+        return admin_primehub
+
     def __getattr__(self, item):
         if item in self.commands:
             return self.commands[item]
@@ -278,20 +317,9 @@ class PrimeHub(object):
             return False
         return True
 
-
-class Module(object):
-
-    def __init__(self, primehub: PrimeHub, **kwargs):
-        self.primehub = primehub
-
-        # attach request method
-        self.request = primehub.request
-        self.request_logs = primehub.request_logs
-        self.request_file = primehub.request_file
-
     @property
     def current_group(self) -> dict:
-        g = self.primehub.primehub_config.current_group
+        g = self.primehub_config.current_group
         if not g:
             group_required()
         if not g.get('id', None):
@@ -306,6 +334,29 @@ class Module(object):
     def group_name(self) -> str:
         return self.current_group['name']
 
+
+class Module(object):
+
+    def __init__(self, primehub: PrimeHub, **kwargs):
+        self.primehub = primehub
+
+        # attach request method
+        self.request = primehub.request
+        self.request_logs = primehub.request_logs
+        self.request_file = primehub.request_file
+
+    @property
+    def current_group(self) -> dict:
+        return self.primehub.current_group
+
+    @property
+    def group_id(self) -> str:
+        return self.primehub.group_id
+
+    @property
+    def group_name(self) -> str:
+        return self.primehub.group_name
+
     @property
     def endpoint(self) -> str:
         return self.primehub.primehub_config.endpoint
@@ -326,6 +377,20 @@ class Module(object):
         self.get_display().display(action, value, self.primehub.stdout)
 
 
+class Dummy(Helpful, Module):
+    """
+    Dummy subcommand
+    """
+    description = None
+
+    def __init__(self, primehub: PrimeHub, description):
+        super(Dummy, self).__init__(primehub)
+        self.description = description
+
+    def help_description(self):
+        return self.description
+
+
 def has_data_from_stdin():
     """
     Check if any data comes from stdin.
